import os
import subprocess
import time
from datetime import datetime

def connect_to_server(ip, port):
    try:
        command = f"adb.exe connect {ip}:{port}"
        result = subprocess.run(command, shell=True, capture_output=True, text=True, encoding='utf-8')
        if "connected" in result.stdout:
            return True
        else:
            print(result.stdout)
            return False
    except Exception as e:
        print(f"连接失败: {e}")
        return False

def query_sms():
    try:
        command = "adb.exe shell content query --uri content://sms/"
        result = subprocess.run(command, shell=True, capture_output=True, text=True, encoding='utf-8')
        if result.returncode == 0:
            return result.stdout
        else:
            print(result.stdout)
            return None
    except Exception as e:
        print(f"获取短信失败: {e}")
        return None

def parse_sms(sms_data):
    sms_list = sms_data.strip().split("Row: ")
    parsed_sms = []

    for sms in sms_list[1:]:
        sms_dict = {}
        lines = sms.split(", ")
        for line in lines:
            if '=' in line:
                key, value = line.split("=", 1)
                sms_dict[key.strip()] = value.strip()
        
        address = sms_dict.get("address", "N/A")
        date_sent = sms_dict.get("date_sent", "N/A")
        date = sms_dict.get("date", "N/A")
        body = sms_dict.get("body", "N/A")
        sim_id = sms_dict.get("sim_id", "N/A")

        date_sent_fmt = datetime.fromtimestamp(int(date_sent) / 1000).strftime('%Y-%m-%d %H:%M:%S') if date_sent.isdigit() else "N/A"
        date_fmt = datetime.fromtimestamp(int(date) / 1000).strftime('%Y-%m-%d %H:%M:%S') if date.isdigit() else "N/A"

        parsed_sms.append({
            "发送方号码": address,
            "发送时间": date_sent_fmt,
            "接收时间": date_fmt,
            "短信内容": body,
            "SIM卡ID": sim_id
        })
    
    parsed_sms.sort(key=lambda x: x["接收时间"])
    return parsed_sms

def display_sms(parsed_sms):
    for sms in parsed_sms:
        print(f"发送方号码: {sms['发送方号码']}")
        print(f"发送时间: {sms['发送时间']}")
        print(f"接收时间: {sms['接收时间']}")
        print(f"短信内容: {sms['短信内容']}")
        print(f"SIM卡ID: {sms['SIM卡ID']}")
        print("-" * 40)

def main():
    try:
        while True:
            ip = input("请输入服务器IP: ")
            port = input("请输入服务器端口: ")

            if connect_to_server(ip, port):
                print("连接成功！按回车键获取短信...")
                input()
                while True:
                    sms_data = query_sms()
                    if sms_data:
                        parsed_sms = parse_sms(sms_data)
                        display_sms(parsed_sms)
                    else:
                        print("未获取到短信。")

                    choice = input("是否重新获取短信？(y/n): ").strip().lower()
                    if choice == 'n':
                        break
                    elif choice == 'q':
                        break
                if choice == 'q':
                    break
            else:
                choice = input("连接失败，是否重新连接？(y/n): ").strip().lower()
                if choice == 'n':
                    break
    except KeyboardInterrupt:
        print("\n检测到 Ctrl+C，退出程序中...")

    subprocess.run("adb.exe disconnect", shell=True)
    print("已断开连接。")

if __name__ == "__main__":
    main()
